@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
+ * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
  *
  * Author:     kirigaya <kirigaya@mkacg.com>
  *
@@ -24,7 +24,7 @@
 
 #include <QWidget>
 
-class AppBody : public QWidget
+class AppBody : public QFrame
 {
     Q_OBJECT
 public:
@@ -33,10 +33,10 @@ public:
     void setText(const QString & text);
 
 private:
-    QString m_title;
-    QString m_bodyText;
+    void updateAlignment();
 
-    QLabel *m_titleLbl;
+private:
+    appBodyLabel *m_titleLbl;
     appBodyLabel *m_bodyLbl;
 };
 
