@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
+ * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
  *
  * Author:     kirigaya <kirigaya@mkacg.com>
  * This program is free software: you can redistribute it and/or modify
@@ -19,23 +19,29 @@
 #ifndef APPBODYLABEL_H
 #define APPBODYLABEL_H
 
-#include <QLabel>
+#include <QFrame>
 
-class appBodyLabel : public QLabel
+class appBodyLabel : public QFrame
 {
     Q_OBJECT
 public:
     explicit appBodyLabel(QWidget *parent = nullptr);
     void setText(const QString &text);
-
-protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
+    QSize minimumSizeHint() const override;
+    void setAlignment(Qt::Alignment alignment);
 
 private:
     const QString holdTextInRect(const QFontMetrics &fm, const QString &text, const QRect &rect) const;
+    void resizeEvent(QResizeEvent *e) override;
+    void paintEvent(QPaintEvent *event) override;
 
 private:
+    void updateLineCount();
+
     QString m_text;
+    int m_lineCount = 0;
+    Qt::Alignment m_alignment;
 };
 
 #endif // APPBODYLABEL_H
