@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 ~ 2017 Deepin Technology Co., Ltd.
+ * Copyright (C) 2014 ~ 2018 Deepin Technology Co., Ltd.
  *
  * Author:     kirigaya <kirigaya@mkacg.com>
  *
@@ -17,22 +17,42 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <DApplication>
 #include "bubblemanager.h"
 #include "notifications_dbus_adaptor.h"
 
+#include <DLog>
+#include <DApplication>
+
+DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 
+#define APP_NAME "deepin-notifications"
+
 int main(int argc, char *argv[])
 {
     DApplication::loadDXcbPlugin();
 
     DApplication app(argc, argv);
     app.setTheme("light");
+    app.setOrganizationName("deepin");
+    app.setApplicationName(APP_NAME);
 
-    BubbleManager manager;
-    NotificationsDBusAdaptor adapter(&manager);
-    manager.registerAsService();
+    if (app.setSingleInstance(APP_NAME, DApplication::UserScope)) {
+        DLogManager::registerConsoleAppender();
+        DLogManager::registerFileAppender();
 
-    return app.exec();
+        BubbleManager manager;
+
+        DDENotifyDBus ddenotify(&manager);
+        NotificationsDBusAdaptor adapter(&manager);
+
+        Q_UNUSED(ddenotify)
+        Q_UNUSED(adapter)
+
+        return app.exec();
+    } else {
+        qWarning() << "An instance has already existed!";
+    }
+
+    return 0;
 }
