@@ -1,8 +1,10 @@
 /*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
+ * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
  *
  * Author:     kirigaya <kirigaya@mkacg.com>
  *
+ * Maintainer: listenerri <listenerri@gmail.com>
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -22,6 +24,7 @@
 
 #include <QObject>
 #include <QSqlDatabase>
+#include <QSqlQuery>
 
 class NotificationEntity;
 class Persistence : public QObject
@@ -35,14 +38,22 @@ public:
     void removeOne(const QString &id);
     void removeAll();
 
-    QList<NotificationEntity> getAll();
+    QString getAll();
+    QString getById(const QString &id);
+
+    // the result starts with offset + 1
+    // If rowcount is - 1, it is obtained from offset + 1 to the last.
+    QString getFrom(int rowCount, const QString &offsetId);
 
 signals:
     void RecordAdded(NotificationEntity *entify);
 
 private:
-//    QList<NotificationEntity*> m_buffer;
+    void attemptCreateTable();
+
+private:
     QSqlDatabase m_dbConnection;
+    QSqlQuery m_query;
 };
 
 #endif // PERSISTENCE_H
